@@ -55,6 +55,7 @@ impl<'a> HandlebarsAMQPExtension for CodeGenerator<'a> {
         self.register_helper("include_more", Box::new(IncludeMoreHelper));
         self.register_helper("pass_by_ref", Box::new(PassByRefHelper));
         self.register_helper("use_str_ref", Box::new(UseStrRefHelper));
+        self.register_helper("use_bytes_ref", Box::new(UseBytesRefHelper));
         self.register_helper("each_argument", Box::new(EachArgumentHelper));
         self.register_helper("amqp_value_ref", Box::new(AMQPValueRefHelper));
         self
@@ -240,21 +241,21 @@ impl HelperDef for PassByRefHelper {
         _: &'reg Handlebars<'_>,
         _: &'rc Context,
         _: &mut RenderContext<'reg, 'rc>,
-    ) -> Result<Option<ScopedJson<'reg, 'rc>>, RenderError> {
+    ) -> Result<ScopedJson<'reg, 'rc>, RenderError> {
         let value = h
             .param(0)
             .ok_or_else(|| RenderError::new("Param not found for helper \"pass_by_ref\""))?;
         let param: AMQPType = serde_json::from_value(value.value().clone())
             .map_err(|_| RenderError::new("Param is not an AMQPType for helper \"pass_by_ref\""))?;
-        let pass_by_ref = match param {
+        let pass_by_ref = matches!(
+            param,
             AMQPType::ShortString
-            | AMQPType::LongString
-            | AMQPType::FieldArray
-            | AMQPType::FieldTable
-            | AMQPType::ByteArray => true,
-            _ => false,
-        };
-        Ok(Some(ScopedJson::Derived(JsonValue::from(pass_by_ref))))
+                | AMQPType::LongString
+                | AMQPType::FieldArray
+                | AMQPType::FieldTable
+                | AMQPType::ByteArray
+        );
+        Ok(ScopedJson::Derived(JsonValue::from(pass_by_ref)))
     }
 }
 
@@ -267,16 +268,35 @@ impl HelperDef for UseStrRefHelper {
         _: &'reg Handlebars<'_>,
         _: &'rc Context,
         _: &mut RenderContext<'reg, 'rc>,
-    ) -> Result<Option<ScopedJson<'reg, 'rc>>, RenderError> {
+    ) -> Result<ScopedJson<'reg, 'rc>, RenderError> {
         let value = h
             .param(0)
             .ok_or_else(|| RenderError::new("Param not found for helper \"use_str_ref\""))?;
         let param = serde_json::from_value::<AMQPType>(value.value().clone()).ok();
-        let use_str_ref = match param {
-            Some(AMQPType::ShortString) | Some(AMQPType::LongString) => true,
-            _ => false,
-        };
-        Ok(Some(ScopedJson::Derived(JsonValue::from(use_str_ref))))
+        let use_str_ref = matches!(
+            param,
+            Some(AMQPType::ShortString) | Some(AMQPType::LongString)
+        );
+        Ok(ScopedJson::Derived(JsonValue::from(use_str_ref)))
+    }
+}
+
+/// Helper to check whether a param is passed using an &[u8] or its real type
+pub struct UseBytesRefHelper;
+impl HelperDef for UseBytesRefHelper {
+    fn call_inner<'reg: 'rc, 'rc>(
+        &self,
+        h: &Helper<'reg, 'rc>,
+        _: &'reg Handlebars<'_>,
+        _: &'rc Context,
+        _: &mut RenderContext<'reg, 'rc>,
+    ) -> Result<ScopedJson<'reg, 'rc>, RenderError> {
+        let value = h
+            .param(0)
+            .ok_or_else(|| RenderError::new("Param not found for helper \"use_bytes_ref\""))?;
+        let param = serde_json::from_value::<AMQPType>(value.value().clone()).ok();
+        let use_bytes_ref = matches!(param, Some(AMQPType::LongString));
+        Ok(ScopedJson::Derived(JsonValue::from(use_bytes_ref)))
     }
 }
 
@@ -316,10 +336,10 @@ impl HelperDef for EachArgumentHelper {
                         AMQPArgument::Value(_) => ("Value".to_owned(), true),
                         AMQPArgument::Flags(_) => ("Flags".to_owned(), false),
                     };
-                    block.set_local_var("@index".to_string(), to_json(&index));
-                    block.set_local_var("@last".to_string(), to_json(index == len - 1));
-                    block.set_local_var("@argument_is_value".to_string(), to_json(&is_value));
-                    if let Some(ref p) = array_path {
+                    block.set_local_var("index", to_json(&index));
+                    block.set_local_var("last", to_json(index == len - 1));
+                    block.set_local_var("argument_is_value", to_json(&is_value));
+                    if let Some(p) = array_path {
                         if index == 0 {
                             let mut path = Vec::with_capacity(p.len() + 1);
                             path.extend_from_slice(p);
@@ -352,7 +372,7 @@ impl HelperDef for AMQPValueRefHelper {
         _: &'reg Handlebars<'_>,
         _: &'rc Context,
         _: &mut RenderContext<'reg, 'rc>,
-    ) -> Result<Option<ScopedJson<'reg, 'rc>>, RenderError> {
+    ) -> Result<ScopedJson<'reg, 'rc>, RenderError> {
         let arg = h
             .param(0)
             .ok_or_else(|| RenderError::new("First param not found for helper \"amqp_value\""))?;
@@ -371,14 +391,14 @@ impl HelperDef for AMQPValueRefHelper {
             AMQPValue::Double(v) => serde_json::to_value(v)?,
             AMQPValue::DecimalValue(v) => serde_json::to_value(v)?,
             AMQPValue::ShortString(v) => serde_json::to_value(format!("\"{}\"", v))?,
-            AMQPValue::LongString(v) => serde_json::to_value(format!("\"{}\"", v))?,
+            AMQPValue::LongString(v) => serde_json::to_value(format!("b\"{}\"", v))?,
             AMQPValue::FieldArray(v) => serde_json::to_value(v)?,
             AMQPValue::Timestamp(v) => serde_json::to_value(v)?,
             AMQPValue::FieldTable(v) => serde_json::to_value(v)?,
             AMQPValue::ByteArray(v) => serde_json::to_value(v)?,
             AMQPValue::Void => JsonValue::Null,
         };
-        Ok(Some(ScopedJson::Derived(value)))
+        Ok(ScopedJson::Derived(value))
     }
 }
 
@@ -388,7 +408,7 @@ mod test {
 
     use std::collections::BTreeMap;
 
-    pub const TEMPLATE: &'static str = r#"
+    pub const TEMPLATE: &str = r#"
 {{protocol.name}} - {{protocol.major_version}}.{{protocol.minor_version}}.{{protocol.revision}}
 {{protocol.copyright}}
 port {{protocol.port}}
@@ -500,13 +520,12 @@ Copyright 1
 Copyright 2
 port 5672
 domain1: LongString
-constant1 = 128
-42 - class1
+constant1= 128
+42- class1
 property1: LongString
-64 - method1
+64- method1
 synchronous: true
 argument1(domain1): LongString
-
 flag1: true
 flag2: false
 "#
